from typing import Any, List


from transformers import pipeline, AutoTokenizer, AutoModelForSequenceClassification
from pymemri.data.loader import load_huggingface_model_for_project

class Model:
    def __init__(self, name: str = None, version: str = None, client = None) -> None:
        """
        A classifier Model should return a list of dictionaries {"label": class_label, "score": class_score} for each class.
        For example, for a binary sentiment classification an example input and output could be:

        ```
        input = ["This is great"]

        output = [
            [{"label": "Positive", "score": 0.9},
             {"label": "Negative", "score": 0.1}]
        ]
        ```

        """
        self.name = name
        self.version = version
        
        model = load_huggingface_model_for_project(project_path="erfan/wa-test-7", client=client)
        tokenizer = AutoTokenizer.from_pretrained("distilroberta-base", model_max_length=512)
        self.pipeline = pipeline("sentiment-analysis", model=model, tokenizer=tokenizer, return_all_scores=True, truncation=True)
        

    def predict(self, x: List[Any]) -> List[Any]:
        
        return self.pipeline(x)
        
