from io import BytesIO

import PIL
from pymemri.data.photo import Photo
from pymemri.data.schema import EmailMessage, Message, Tweet
from pymemri.pod.client import PodClient


def item_to_data(item, client):
    if isinstance(item, Photo):
        return photo_to_PIL(item, client)
    elif isinstance(item, EmailMessage) or isinstance(item, Message):
        return item.content
    elif isinstance(item, Tweet):
        return item.message
    else:
        raise NotImplementedError(
            f"Converting Item of type {type(item)} is not implemented."
        )


def photo_to_PIL(photo: Photo, client: PodClient):
    photo = client.get_photo(photo.id)
    return PIL.Image.open(BytesIO(photo.data))
